using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO.Ports;

namespace terminal
{
    public partial class Form1 : Form
    {
        enum Input_format
        {
            ascii,
            dec,
            hex,
        };
 
        SerialPort serialPort1;
        string prijata_data = "";
        Input_format input_format = Input_format.hex;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            serialPort1 = new SerialPort();
            serialPort1.BaudRate = 115200;
            serialPort1.Handshake = Handshake.None;
            serialPort1.Parity = Parity.None;
            serialPort1.DataBits = 8;
            serialPort1.StopBits = StopBits.One;
            serialPort1.ReadTimeout = 1000;
            serialPort1.WriteTimeout = 1000;
            serialPort1.DataReceived += new SerialDataReceivedEventHandler(serialPort1_DataReceived);

            timer1.Enabled = true;

            radioButton_asc.Tag = Input_format.ascii;
            radioButton_asc.Click += new EventHandler(radioButton_Click);
            radioButton_dec.Tag = Input_format.dec;
            radioButton_dec.Click += new EventHandler(radioButton_Click);
            radioButton_hex.Tag = Input_format.hex;
            radioButton_hex.Click += new EventHandler(radioButton_Click);
        }

        void radioButton_Click(object sender, EventArgs e)
        {
            input_format = (Input_format)((RadioButton)sender).Tag;
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (serialPort1.IsOpen)
            {
                serialPort1.Close();
            }
        }
  
 
 


        private void button_connect_Click(object sender, EventArgs e)
        {
            try
            {
                if (button_connect.Text == "Connect")
                {
                    serialPort1.PortName = comboBox1.Text;
                    serialPort1.Open();
                    button_connect.Text = "Disconnect";
                    toolStripStatusLabel1.Text = "connected";
                }
                else
                {
                    serialPort1.Close();
                    button_connect.Tag = 0;
                    button_connect.Text = "Connect";
                    toolStripStatusLabel1.Text = "disconnected";
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Connect: " + ex.Message);
            }
        }

        private void button_send_Click(object sender, EventArgs e)
        {
            try
            {
                if (serialPort1.IsOpen)
                {
                    byte[] write_buffer = new byte[1];
                    switch (input_format)
                    {
                        case Input_format.ascii:
                            serialPort1.Write(textBox1.Text);
                            textBox_tx.Text = "\"" + textBox1.Text + "\"" + "\r\n" + textBox_tx.Text;
                            break;
                        case Input_format.dec:
                            Byte.TryParse(textBox1.Text, System.Globalization.NumberStyles.Integer, null, out write_buffer[0]);
                            serialPort1.Write(write_buffer, 0, 1);
                            textBox_tx.Text = textBox1.Text + "\r\n" + textBox_tx.Text;
                            break;
                        case Input_format.hex:
                            Byte.TryParse(textBox1.Text, System.Globalization.NumberStyles.HexNumber, null, out write_buffer[0]);
                            serialPort1.Write(write_buffer, 0, 1);
                            textBox_tx.Text = "0x" + textBox1.Text + "\r\n" + textBox_tx.Text;
                            break;
                        default:
                            break;
                    }
                }
                else
                {
                    MessageBox.Show("Not Connected", "", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        private void button_clear_Click(object sender, EventArgs e)
        {
            textBox_rx.Text = textBox_tx.Text = "";
        }

        private void button_macro_Click(object sender, EventArgs e)
        {
            try
            {
                if (serialPort1.IsOpen)
                {
                    byte[] write_buffer = new byte[18];
                    write_buffer[0] = (4 << 5) + 18;
                    for (int i = 0; i < 16; i++)
                    {
                        write_buffer[i + 1] = (byte)(2 * i + 3);
                    }
                    write_buffer[17] = 0;
                    for (int i = 0; i < (write_buffer.Length - 1); i++)
                    {
                        write_buffer[17] ^= write_buffer[i];
                    }

                    serialPort1.Write(write_buffer, 0, 18);

                    textBox_tx.Text = "Macro\r\n" + textBox_tx.Text;
                    
                }
                else
                {
                    MessageBox.Show("Not Connected", "", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
            catch (Exception ex)
            {
                //MessageBox.Show(ex.Message);
                throw;
            }

        }





        void serialPort1_DataReceived(object sender, SerialDataReceivedEventArgs e)
        {
            try
            {
                StringBuilder temp = new StringBuilder("");
                byte[] b = new byte[serialPort1.BytesToRead];
                for (int i = 0; i < b.Length; i++)
                {
                    b[i] = (byte)serialPort1.ReadByte();
                    temp.AppendFormat("{0:X2} ", b[i]);
                }
                prijata_data = temp.ToString();
            }
            catch (Exception ex)
            {
                MessageBox.Show("Data_received: " + ex.Message);
            }
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            if (prijata_data != "")
            {
                textBox_rx.Text = prijata_data + "\r\n" + textBox_rx.Text;
                prijata_data = "";
            }
        }




    }
}